Description Usage Arguments Value
View source: R/sem_lulc_predict.R
Compute the posterior predictive distribution of landscape variables from a fitted SEM, possibly conditioned on specified values of the latent factor(s).
1 | sem_lulc_predict(fit, data, d, newZ = NULL, linpred = FALSE)
|
fit |
Object of class |
data |
The data list passed to |
d |
Integer in 1, ..., D indicating which landscape variable to simulate. |
newZ |
Matrix of dimension |
linpred |
Logical indicating whether to return the linear predictor (the
default is |
List with elements
XAn iter x
N_new matrix containing posterior samples of the predicted landscape variable.
g_mu_XAn iter x N_new matrix containing posterior samples of the linear
predictor evaluated at the specified values of Z.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.